import fs from 'node:fs';
import path from 'node:path';
export function ensureDirectoryExists(directoryName) {
    if (!fs.existsSync(directoryName)) {
        fs.mkdirSync(directoryName, { recursive: true });
    }
}
export function saveResponse({ directoryName, data, customFilePath }) {
    ensureDirectoryExists(`${directoryName}/mocks`);
    const filePath = path.join(directoryName, customFilePath);
    ensureDirectoryExists(path.dirname(filePath));
    fs.writeFileSync(filePath, JSON.stringify(data, null, 2));
}
export function onAxiosRequestFulfilled({ response, providerConfigKey, connectionId, syncName }) {
    if (!providerConfigKey) {
        return response;
    }
    const directoryName = `${process.env['NANGO_MOCKS_RESPONSE_DIRECTORY'] ?? ''}${providerConfigKey}`;
    const method = response.config.method?.toLowerCase() || 'get';
    if (response.request.path.includes(`/connection/${connectionId}?provider_config_key=${providerConfigKey}`)) {
        const connection = response.data;
        // getConnection could be getMetadata as well which would be cached
        saveResponse({
            directoryName,
            data: { metadata: connection.metadata, connection_config: connection.connection_config },
            customFilePath: 'mocks/nango/getConnection.json'
        });
        saveResponse({
            directoryName,
            data: connection.metadata,
            customFilePath: 'mocks/nango/getMetadata.json'
        });
        return response;
    }
    const pathname = response.request.path.split('?')[0];
    const strippedPath = pathname.replace('/', '');
    saveResponse({
        directoryName,
        data: response.data,
        customFilePath: `mocks/nango/${method}/${strippedPath}/${syncName}.json`
    });
    return response;
}
//# sourceMappingURL=response-saver.service.js.map